# Developers

### **Jing Liu**
**Huazhong University of Science and Technology**  
**Email:** <liujingphys@hust.edu.cn>  
**Biography:** Jing Liu is currently an associate professor in the National Precise Gravity 
Measurement Facility, Huazhong University of Science and Technology. His main research interests 
focus on the topics in quantum metrology, quantum control, quantum information theory, and 
foundations of quantum mechanics, especially the design of high-precision measurement schemes 
using the features of quantum mechanics.

---

### **Rafał Demkowicz-Dobrzański**  
**University of Warsaw**  
**Email:** <Rafal.Demkowicz-Dobrzanski@fuw.edu.pl>  
**Biography:** Rafał Demkowicz-Dobrzański is an associate professor at the Faculty of Physics, 
University of Warsaw. He is a theorist actively working in the field of quantum metrology, 
who developed methods to identify fundamental limits in quantum metrology in presence of 
decoherence.

---
### **Mao Zhang** 
**Huazhong University of Science and Technology**  
**Email:** <zhangmao2018@foxmail.com>  
**Biography:** Ms. Zhang is currently a Ph.D. student in the National Precise Gravity 
Measurement Facility, School of Physics, Huazhong University of Science and Technology. 
Her research focuses on the quantum metrology and quantum control, especially the design 
of control enhanced quantum metrological schemes. 

---
### **Huai-Ming Yu**  
**Huazhong University of Science and Technology**  
**Email:** <HuaimingYuuu@gmail.com>  
**Biography:** Huai-Ming Yu is a M.Sc. student at the School of Physics, Huazhong University of 
Science and Technology. His research interests lie primarily in the fields of quantum information,
quantum control, quantum foundations, as well as scientific programming and its applications in
quantum technology.

---

# Advisors

### **Haidong Yuan**  
**The Chinese University of Hong Kong**  
**Biography:** Haidong Yuan is an associate professor at the Department of Mechanical 
and Automation Engineering, The Chinese University of Hong Kong.

---

### **Xiaoguang Wang**  
**Zhejiang University**  
**Biography:** Xiaoguang Wang is a professor at the Department of Physics, Zhejiang University.
